+++
title = "Url encoding in links"
description = "Encoding of non-URL characters in links"
tags = ["links", "escaping", "url", "encoding"]
draft = false
+++

Below links are invalid, they are there just for test purpose.

-   [A dummy Jira JQL link](https://jira.example.com/issues/?jql=(project=MYPRJ)AND(assignee=currentUser()))
-   [A dummy Jira JQL link with spaces](https://jira.example.com/issues/?jql=(project=MYPRJ)AND(assignee=currentUser())AND(labels%20in%20(foo)))
